jaclearn.logic.propositional.logic\_induction
=============================================

.. automodule:: jaclearn.logic.propositional.logic_induction

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      search
   
   

   
   
   



.. rubric:: Submodules
.. autosummary::
   :toctree:
   :template: base.rst
   :recursive:

   logic_induction
   setup









.. rubric:: Functions

.. autofunction:: search


